Surface charts
==============


Data that is arranged in columns or rows on a worksheet can be plotted in a
surface chart. A surface chart is useful when you want to find optimum
combinations between two sets of data. As in a topographic map, colors and
patterns indicate areas that are in the same range of values.

By default all surface charts are 3D. 2D wireframe and contour charts are
created by setting the rotation and perspective.


.. literalinclude:: surface.py


.. image:: surface.png
   :alt: "Sample surface charts"
